==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/man/yeastPkgBuilder.Rd <==
\name{yeastPkgBuilder}
\alias{yeastPkgBuilder}
\alias{findYGChrLength}
\title{Functions to do a data package for yeast genome}
\description{
  These functions builds a data package for yeast genome using data from
  Yeast Genome web site of Stanford University, KEGG, and Gene Ontology.
}
\usage{
yeastPkgBuilder(pkgName, pkgPath, base = "", srcUrls = c(KEGG =
getSrcUrl("KEGG", organism = "yeast"), GO = getSrcUrl("GO")), version =
"1.1.0", makeXML = TRUE, author = c(name = "who", address =
"who@email.com"), fromWeb = TRUE)
findYGChrLength(yGenoUrl =
"ftp://genome-ftp.stanford.edu/pub/yeast/data_download/", yGenoName =
"chromosomal_feature/chromosomal_feature.tab", toKeep = c(5, 7), sep = "\t")
}

\arguments{
  \item{pkgName}{\code{pkgName} a character string for the name of the
    data package to be built}
  \item{base}{\code{base} a matrix with two columns with the first one
    being probe ids and the second one being their mappings to ORF (Open
    Reading Frame) ids. Columns have the name "probe" and "orf"}
  \item{pkgPath}{\code{pkgPath} a character string for the directory
    where the data package to be built will be stored}
  \item{srcUrls}{\code{srcUrls} a named vector of strings for the urls
    for KEGG (\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}) and GO
    (http://www.godatabase.org/dev/database/archive/2003-05-01/go\_200305-termdb.xml.gz). The urls may change over time} 
  \item{version}{\code{version} a character string for the version
    number of the data package to be built}
  \item{makeXML}{\code{makeXML} a boolean to indicate whether an XML
    version of the data will be generated}
  \item{author}{\code{author} a named vector of two character strings
    with a name element for the name and an address element of email
    address of the maintainer of the data package}
  \item{fromWeb}{\code{fromWeb} a boolean to indicate whether the data
    from GO should be downloaded from the web or read locally. The url
    for GO should be the file name of a local file if fromWeb is
    FALSE. For windows users, the data file from GO should be
    downloaded/unzipped manually and set the url for GO to be the name
    of the local file}
  \item{yGenoUrl}{\code{yGenoUrl} a character string for the url to the
    ftp iste where download files are stored. Defaulted to an url that
    was correct at the time of writting}
  \item{yGenoName}{\code{yGenoName} a character string for the name of
    the data file that contains chromosome information
    ("chrosomomal\_featur/chromosomal\_feature.tab")}
  \item{toKeep}{\code{toKeep} a vector of integers for the numbers of the
    columns that will be kept when the file is read}
  \item{sep}{\code{sep} a character of string for the delimiter used by
    the file to separate columns}
}
\details{
  Annotation elements are limited to those provided by Yeast Genome
  (gene name, chromosome number, chromosomal location, GO id, and
  evidence code), KEGG (path and enzyme data) and GO (GO mappings)
}
\value{
  \code{findYGChrLength} returns a named vector of integers with
  chromosome numbers names and length of chromosomes as values. 
}
\references{\url{http://www.yeastgenome.org}}
\author{Jianhua Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities through R}
\examples{
# The code runs only when invoked by an user. 
if(interactive()){
  findYGChrLength()
}
}
\keyword{manip}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/man/yeastPkgBuilder.Rd <==
\name{yeastPkgBuilder}
\alias{yeastPkgBuilder}
\alias{findYGChrLength}
\title{Functions to do a data package for yeast genome}
\description{
  These functions builds a data package for yeast genome using data from
  Yeast Genome web site of Stanford University, KEGG, and Gene Ontology.
}
\usage{
yeastPkgBuilder(pkgName, pkgPath, base = "", srcUrls = c(KEGG =
getSrcUrl("KEGG", organism = "yeast"), GO = getSrcUrl("GO")), version =
"1.1.0", makeXML = TRUE, author = list(author = "who", maintainer =
"who@email.com"), fromWeb = TRUE)
}
\arguments{
  \item{pkgName}{\code{pkgName} a character string for the name of the
    data package to be built}
  \item{base}{\code{base} a matrix with two columns with the first one
    being probe ids and the second one being their mappings to ORF (Open
    Reading Frame) ids. Columns have the name "probe" and "orf"}
  \item{pkgPath}{\code{pkgPath} a character string for the directory
    where the data package to be built will be stored}
  \item{srcUrls}{\code{srcUrls} a named vector of strings for the urls
    for KEGG (\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}) and GO
    (http://www.godatabase.org/dev/database/archive/2003-05-01/go\_200305-termdb.xml.gz). The urls may change over time} 
  \item{version}{\code{version} a character string for the version
    number of the data package to be built}
  \item{makeXML}{\code{makeXML} a boolean to indicate whether an XML
    version of the data will be generated}
  \item{author}{\code{author} a named vector of two character strings
    with a name element for the name and an address element of email
    address of the maintainer of the data package}
  \item{fromWeb}{\code{fromWeb} a boolean to indicate whether the data
    from GO should be downloaded from the web or read locally. The url
    for GO should be the file name of a local file if fromWeb is
    FALSE. For windows users, the data file from GO should be
    downloaded/unzipped manually and set the url for GO to be the name
    of the local file}
}
\details{
  Annotation elements are limited to those provided by Yeast Genome
  (gene name, chromosome number, chromosomal location, GO id, and
  evidence code), KEGG (path and enzyme data) and GO (GO mappings)
}
\value{
  \code{findYGChrLength} returns a named vector of integers with
  chromosome numbers names and length of chromosomes as values. 
}
\references{\url{http://www.yeastgenome.org}}
\author{Jianhua Zhang}
\note{The functions are part of the Bioconductor project at Dana-Farber
  Cancer Institute to provide Bioinformatics functionalities through R}
\examples{
# Not provided. 
}
\keyword{manip}
